Overrides
==========

.. automodule:: drain_swamp.version_file._overrides
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: construct setuptools-scm PRETEND_VERSION environment variable string
   :ignore-module-all:
